MAYBE

The TRS could not be proven terminating. The proof attempt took 4650 ms.

The following DP Processors were used


Problem 1 was processed with processor PolynomialLinearRange4iUR (0ms).
 | – Problem 2 was processed with processor PolynomialLinearRange4iUR (0ms).
 |    | – Problem 3 remains open; application of the following processors failed [DependencyGraph (0ms), PolynomialLinearRange4iUR (82ms), DependencyGraph (1ms), PolynomialLinearRange8NegiUR (1555ms), DependencyGraph (1ms), ReductionPairSAT (2366ms), DependencyGraph (1ms), SizeChangePrinciple (4ms)].

The following open problems remain:



Open Dependency Pair Problem 3

Dependency Pairs

f#(a, f(x, a)) → f#(a, f(f(a, a), x))

Rewrite Rules

f(a, f(x, a)) → f(f(a, f(f(a, a), x)), a)

Original Signature

Termination of terms over the following signature is verified: f, a


Problem 1: PolynomialLinearRange4iUR



Dependency Pair Problem

Dependency Pairs

f#(a, f(x, a)) → f#(f(a, a), x)f#(a, f(x, a)) → f#(a, a)
f#(a, f(x, a)) → f#(f(a, f(f(a, a), x)), a)f#(a, f(x, a)) → f#(a, f(f(a, a), x))

Rewrite Rules

f(a, f(x, a)) → f(f(a, f(f(a, a), x)), a)

Original Signature

Termination of terms over the following signature is verified: f, a

Strategy


Polynomial Interpretation

Improved Usable rules

f(a, f(x, a)) → f(f(a, f(f(a, a), x)), a)

The following dependency pairs are strictly oriented by an ordering on the given polynomial interpretation, thus they are removed:

f#(a, f(x, a)) → f#(f(a, a), x)f#(a, f(x, a)) → f#(f(a, f(f(a, a), x)), a)

Problem 2: PolynomialLinearRange4iUR



Dependency Pair Problem

Dependency Pairs

f#(a, f(x, a)) → f#(a, a)f#(a, f(x, a)) → f#(a, f(f(a, a), x))

Rewrite Rules

f(a, f(x, a)) → f(f(a, f(f(a, a), x)), a)

Original Signature

Termination of terms over the following signature is verified: f, a

Strategy


Polynomial Interpretation

Improved Usable rules

f(a, f(x, a)) → f(f(a, f(f(a, a), x)), a)

The following dependency pairs are strictly oriented by an ordering on the given polynomial interpretation, thus they are removed:

f#(a, f(x, a)) → f#(a, a)